require 'xds_b.pnr.slot'
require 'xds_b.pnr.code'

xds_b.pnr.submissionSet = {}
xds_b.pnr.submissionSet.id = {}
xds_b.pnr.submissionSet.classification = {}
xds_b.pnr.submissionSet.code = {}
xds_b.pnr.submissionSet.author = {}

local addElement = node.addElement
local setAttr = node.setAttr

local SubmissionSetAddHelp = {
   title="xds_b.pnr.submissionSet.add",
   usage="xds_b.pnr.submissionSet.add{target=<root tag>, submissionSetId=<value>}",
   description="This function will add a submissionSet construct to the xml document.",
   returns={
      "The node tree presenting the resulting xml construct"
   },
   parameters={
      target="The root xml where the submissionSet XML will be inserted",
      submissionSetId="The submission set Id"
   },
   examples={"local SubmissionSetXML = xds_b.pnr.submissionSet.add{target=Root, submissionSetId='SubmissionSet1'}"}
}

function xds_b.pnr.submissionSet.add(I)
   ihe.help.check(I, SubmissionSetAddHelp)
   
   local SS = addElement(I.target, 'rim:RegistryPackage')
   setAttr(SS, 'id', I.submissionSetId)
   setAttr(SS, 'objectType', 'urn:oasis:names:tc:ebxml-regrep:ObjectType:RegistryObject:RegistryPackage')
   
   return SS
end

ihe.help.set{func=xds_b.pnr.submissionSet.add, info=SubmissionSetAddHelp}

local SubmissionSetAuthorAddHelp = {
   title="xds_b.pnr.submissionSet.author.add",
   usage="xds_b.pnr.submissionSet.author.add{target=<root tag>, submissionSetId=<value>, id=<value>}",
   description="This function will add an author construct to the xml document.",
   returns={
      "The node tree presenting the resulting xml construct"
   },
   parameters={
      target="The submission set root xml where the author XML will be inserted",
      submissionSetId="The submission set Id",
      id="The Id associated with the author XML"
   },
   examples={[[local AuthorXML = xds_b.pnr.submissionSet.author.add{target=SubmissionSetRoot, submissionSetId='SubmissionSet1', 
      id='id_36'}]]}
}

function xds_b.pnr.submissionSet.author.add(I)
   ihe.help.check(I, SubmissionSetAuthorAddHelp)
   
   local C = addElement(I.target, 'rim:Classification')
   setAttr(C, 'classificationScheme', 'urn:uuid:a7058bb9-b4e4-4307-ba5b-e3f0ab85e12d')
   setAttr(C, 'classifiedObject', I.submissionSetId)
   setAttr(C, 'nodeRepresentation', '')
   setAttr(C, 'objectType', 'urn:oasis:names:tc:ebxml-regrep:ObjectType:RegistryObject:Classification')
   setAttr(C, 'id', I.id)
   
   return C
end

ihe.help.set{func=xds_b.pnr.submissionSet.author.add, info=SubmissionSetAuthorAddHelp}

local SubmissionSetIdAddHelp = {
   title="xds_b.pnr.submissionSet.id.add",
   usage="xds_b.pnr.submissionSet.id.add{target=<root tag>, idType=<value>, id=<value>, value=<value>}",
   description="This function will add an id construct to the xml document.",
   returns={
      "The node tree presenting the resulting xml construct"
   },
   parameters={
      target="The submission set root xml where the id XML will be inserted",
      idType="The kind of Id i.e. source, patient or unique",
      id="The Id associated with the Id within the request",
      submissionSetId="The Id of the submission set enclosing the id",
      value="The value associated with the Id XML"
   },
   examples={[[local IdXML = xds_b.pnr.submissionSet.id.add{target=SubmissionSetRoot, idType='patient', id='id_37', 
      value='58bdf99f28b44c7^^^&1.3.6.1.4.1.21367.2005.3.7&ISO'}]]}
}

function xds_b.pnr.submissionSet.id.add(I)
   ihe.help.check(I, SubmissionSetIdAddHelp)
   
   local EI = addElement(I.target, 'rim:ExternalIdentifier')
   setAttr(EI, 'identificationScheme', '')
   setAttr(EI, 'value', I.value)
   setAttr(EI, 'objectType', 'urn:oasis:names:tc:ebxml-regrep:ObjectType:RegistryObject:ExternalIdentifier')
   setAttr(EI, 'id', I.id)
   setAttr(EI, 'registryObject', I.submissionSetId)
   
   if 'unique' == I.idType then
      EI.identificationScheme = 'urn:uuid:96fdda7c-d067-4183-912e-bf5ee74998a8'
      xds_b.pnr.name.add{target=EI, name='XDSSubmissionSet.uniqueId'}
   elseif 'source' == I.idType then
      EI.identificationScheme = 'urn:uuid:554ac39e-e3fe-47fe-b233-965d2a147832'      
      xds_b.pnr.name.add{target=EI, name='XDSSubmissionSet.sourceId'}
   elseif 'patient' == I.idType then
      EI.identificationScheme = 'urn:uuid:6b5aea1a-874d-4603-a4bc-96a0a7b38446'      
      xds_b.pnr.name.add{target=EI, name='XDSSubmissionSet.patientId'}
   end
  
   return EI
end

ihe.help.set{func=xds_b.pnr.submissionSet.id.add, info=SubmissionSetIdAddHelp}

local SubmissionSetClassificationAddHelp = {
   title="xds_b.pnr.submissionSet.classification.add",
   usage="xds_b.pnr.submissionSet.classification.add{target=<root tag>, submissionSetId=<value>, id=<value>}",
   description="This function will add a classification construct construct to the xml document.",
   returns={
      "The node tree presenting the resulting xml construct"
   },
   parameters={
      target="The submission set root xml where the classification XML will be inserted",
      submissionSetId="The submissionSet Id",
      id="The Id associated with the classification within the request"
   },
   examples={"local SubmissionSetXML = xds_b.pnr.submissionSet.add{target=Root, id='SubmissionSet1'}"}
}

function xds_b.pnr.submissionSet.classification.add(I)
   ihe.help.check(I, SubmissionSetClassificationAddHelp)
   
   local C = addElement(I.target, 'rim:Classification')
   setAttr(C, 'classifiedObject', I.submissionSetId)
   setAttr(C, 'classificationNode', 'urn:uuid:a54d6aa5-d40d-43f9-88c5-b4633d873bdd')
   setAttr(C, 'objectType', 'urn:oasis:names:tc:ebxml-regrep:ObjectType:RegistryObject:Classification')
   setAttr(C, 'id', I.id)
   
   return C
end

ihe.help.set{func=xds_b.pnr.submissionSet.classification.add, info=SubmissionSetClassificationAddHelp}
